From c0c3f8b86966079659d0085cfe58a4b6b6bdc124 Mon Sep 17 00:00:00 2001
From: Aleksander Alekseev <aleksander@timescale.com>
Date: Tue, 16 Jul 2024 20:50:36 +0300
Subject: [PATCH v3 1/2] Add PqMsg_Progress definition

Introduce a macro definition for 'P' message tag used in leader/worker
protocol.

Aleksander Alekseev, reviewed by Nathan Bossart.
Discussion: https://postgr.es/m/CAJ7c6TNTd09AZq8tGaHS3LDyH_CCnpv0oOz2wN1dGe8zekxrdQ@mail.gmail.com
---
 src/backend/utils/activity/backend_progress.c | 4 ++--
 src/include/libpq/protocol.h                  | 2 ++
 2 files changed, 4 insertions(+), 2 deletions(-)

diff --git a/src/backend/utils/activity/backend_progress.c b/src/backend/utils/activity/backend_progress.c
index bfb9b7704b..c78c5eb507 100644
--- a/src/backend/utils/activity/backend_progress.c
+++ b/src/backend/utils/activity/backend_progress.c
@@ -92,7 +92,7 @@ void
 pgstat_progress_parallel_incr_param(int index, int64 incr)
 {
 	/*
-	 * Parallel workers notify a leader through a 'P' protocol message to
+	 * Parallel workers notify a leader through a PqMsg_Progress message to
 	 * update progress, passing the progress index and incremented value.
 	 * Leaders can just call pgstat_progress_incr_param directly.
 	 */
@@ -102,7 +102,7 @@ pgstat_progress_parallel_incr_param(int index, int64 incr)
 
 		initStringInfo(&progress_message);
 
-		pq_beginmessage(&progress_message, 'P');
+		pq_beginmessage(&progress_message, PqMsg_Progress);
 		pq_sendint32(&progress_message, index);
 		pq_sendint64(&progress_message, incr);
 		pq_endmessage(&progress_message);
diff --git a/src/include/libpq/protocol.h b/src/include/libpq/protocol.h
index 4b8d440365..554e6921d4 100644
--- a/src/include/libpq/protocol.h
+++ b/src/include/libpq/protocol.h
@@ -64,6 +64,8 @@
 #define PqMsg_CopyDone				'c'
 #define PqMsg_CopyData				'd'
 
+/* These are the codes used by parallel leader/worker protocol. */
+#define PqMsg_Progress              'P'
 
 /* These are the authentication request codes sent by the backend. */
 
-- 
2.45.2

